package urgrip.toolbar;

import com.ur.urcap.api.contribution.toolbar.ToolbarAPIProvider;
import com.ur.urcap.api.contribution.toolbar.ToolbarContext;
import com.ur.urcap.api.contribution.toolbar.swing.SwingToolbarContribution;
import com.ur.urcap.api.domain.io.DigitalIO;

import javax.swing.*;
import java.awt.*;
import java.util.*;

class MyToolbarContribution implements SwingToolbarContribution {
    private static final int VERTICAL_SPACE = 10;
    private static final int HEADER_FONT_SIZE = 24;

    private final ToolbarContext context;
    private final ToolbarAPIProvider apiProvider;
    private final IOHandler ioHandler;
    private JLabel demoToolStatus;
    private HashMap<String, JCheckBox> boxes=new HashMap<>();
    private DigitalIO out0,out1, in0, in1;
    private JButton bGrip;
    private JButton bRelease;
    private JButton bBlow;
    private JButton couple;
    private JButton decouple;
    private JButton bCouple;
    private JButton bDecouple;


    MyToolbarContribution(ToolbarContext context) {
        this.context = context;
        this.apiProvider = context.getAPIProvider();
        this.ioHandler = new IOHandler(this.apiProvider.getApplicationAPI().getIOModel());
    }

    @Override
    public void openView() {

    }

    @Override
    public void closeView() {

    }

    private void InitializeIO() {
        out0 = 	ioHandler.getDigitalIO("tool_out[0]");
        out1 = 	ioHandler.getDigitalIO("tool_out[1]");
        in0 = 	ioHandler.getDigitalIO("tool_in[0]");
        in1 = 	ioHandler.getDigitalIO("tool_in[1]");
    }

    public void buildUI(JPanel jPanel) {
        jPanel.setLayout(new BoxLayout(jPanel, BoxLayout.Y_AXIS));
        jPanel.add(createHeader());
        jPanel.add(createVerticalSpace());
        jPanel.add(createButtons());
        jPanel.add(createInfo());
    }

    private Box createHeader() {
        Box headerBox = Box.createHorizontalBox();
        headerBox.setAlignmentX(Component.CENTER_ALIGNMENT);

        JLabel header = new JLabel("Gripper");
        header.setFont(header.getFont().deriveFont(Font.BOLD, HEADER_FONT_SIZE));
        headerBox.add(header);
        return headerBox;
    }

    private Box createButtons() {
        Box box = Box.createHorizontalBox();

        bGrip = new JButton("grip");
        box.add(bGrip);
        new MyButton(bGrip, new HandleButton() {
            @Override public void action() {
                out0.setValue(true);
            }
        });

        bRelease = new JButton("release");
        box.add(bRelease);
        new MyButton(bRelease, new HandleButton() {
            @Override public void action() {
                out0.setValue(false);
            }
        });

        bBlow = new JButton("blow out");
        box.add(bBlow);
        new MyButton(bBlow, new HandleButton() {
            @Override public void action() {
                out0.setValue(false);
            }
        });

        bCouple = new JButton("couple");
        box.add(bCouple);
        new MyButton(bCouple, new HandleButton() {
            @Override public void action() {
                out0.setValue(false);
            }
        });

        bDecouple = new JButton("decouple");
        box.add(bDecouple);
        new MyButton(bDecouple, new HandleButton() {
            @Override public void action() {
                out0.setValue(false);
            }
        });
        return box;
    }

    private Box createInfo() {
        Box infoBox = Box.createVerticalBox();
        infoBox.setAlignmentX(Component.CENTER_ALIGNMENT);
        demoToolStatus = new JLabel();
        demoToolStatus.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));

        infoBox.add(demoToolStatus);
        return infoBox;
    }

    private Component createVerticalSpace() {
        return Box.createRigidArea(new Dimension(0, VERTICAL_SPACE));
    }

    private void updateText(String text) {
        SwingUtilities.invokeLater(() -> demoToolStatus.setText("<HTML>" + text +"</HTML>"));
    }



}
